3.36.15 (2023-03-24)
====================
👷 Bug fixes
------------

- testlib: define properly a generate_tzdatetime method with timezone (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/716)

🤖 Continuous integration
-------------------------

- avoid launching duplicated migractions tests
- clean CI of unused jobs
- disable can-i-merge
- don't wait for tests to start QA jobs
- smoke_test: add timeout to request to avoid hanging up for too long
- smoke_test: handle ConnectionError situation
- test-cube-skeleton: ensure we use the same python version for smoke test than py3-* tests

3.36.14 (2023-03-02)
====================
👷 Bug fixes
------------

- sphinx-theme 1.0 breaks doc build

3.36.13 (2023-03-02)
====================
👷 Bug fixes
------------

- make sure we only install yapps2-logilab by updating depencies
- tried to format a string while missing one formatting argument

3.36.12 (2023-01-17)
====================
🎉 New features
---------------

- skeleton: remove format=pylint option from tox because it's better without it

3.36.11 (2023-01-12)
====================
👷 Bug fixes
------------

- avoid risking new cubes to install pre-release version of black
- formrenderers: use UStringIO instead of list to keep the same api as self.w (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/597)
- schema_exporters: Add missing description field for relations (e.g `in_state`) to schema exporter

3.36.10 (2022-11-15)
====================
👷 Bug fixes
------------

- hook: correct a typo, self.warn doesn't exist

3.36.9 (2022-10-04)
===================
👷 Bug fixes
------------

- attr: when an entity is not existing always return None when fetching its attributes (#599)
- web.views: escape text from the undohistory view (#598)

🤷 Various changes
------------------

- delete unused translations from \*.po files (#600)
- skeleton: add `long_description_content_type` in setup.py

3.36.8 (2022-09-22)
===================
👷 Bug fixes
------------

- startup_views: raise AuthenticationError if anon access is disabled on
  StartupView (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/595)

3.36.7 (2022-09-14)
===================
👷 Bug fixes
------------

- bookmark: do not escape the xaddrelation view from ajaxedit module

3.36.6 (2022-08-30)
===================
👷 Bug fixes
------------

- pyramid: Redirect to the wanted URL after a successfully loggedin (to #584)
- xss: Ensure to use the xml_escape method on entity attributes
- perf: Restore initial performances by removing the uneccessary join

3.36.5 (2022-07-21)
===================
👷 Bug fixes
------------

- schema_exporters: handle symmetrical relation in schema export. (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/568)

🤷 Various changes
------------------

- feat(markdown)!: update Mardown version to 3.4 and rewrite urlize extension (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/569)

3.36.4 (2022-07-13)
===================

- merge 3.35.6 into 3.36

3.36.3 (2022-06-03)
===================
👷 Bug fixes
------------

- pyramid: adapt TestApp.put_json method to CSRF

3.36.2 (2022-06-01)
===================
🎉 New features
---------------

- pkg: upgrade version of waitress to 2.1.1 or more, for security reason. (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/543)

👷 Bug fixes
------------

- base64.decodestring is deprecated and has been removed
- pyramid: adapt TestApp.post_json method to CSRF
- pyramid: try to get "/login" if "/" is forbidden

3.36.1 (2022-03-31)
===================
👷 Bug fixes
------------

- rql2sql: upgrade RQL version to fix translation of ``NOT EXISTS(X eid Y)`` (`#528 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/528>`_)
- view: don't escape html tags inside image previews

3.36.0 (2022-03-14)
===================
🎉 New features
---------------

- markdown: load extra extensions to render tables (`#515 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/515>`_)
- schema_exporter: add a parameter to export schema as dict (`#522 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/522>`_)

📝 Documentation
----------------

- fix sidebar table of content
- improve basic tutorial
- improve home and sidebar
- improve setup instructions
- improve skeleton readme
- set version number
- use relative links for static resources
- use right number of characters for titles
- use sphinx_book_theme
